@@ -404,7 +404,7 @@ def start_server():
             (PREFIX, GoferHandler),
             (
                 url_path_join(
-                    os.environ['JUPYTERHUB_SERVICE_PREFIX'], 'oauth_callback'
+                    os.environ['JUPYTERHUB_BASE_URL'], 'hub', 'oauth_callback'
                 ),
                 HubOAuthCallbackHandler,
             )
